@@ -66,6 +66,9 @@ AuthDialog::AuthDialog(const QString &actionId,
 
     setupUi(this);
 
+    connect(userCB, QOverload<int>::of(&QComboBox::currentIndexChanged),
+            this, &AuthDialog::checkSelectedUser);
+
     connect(buttonBox, &QDialogButtonBox::accepted, this, &AuthDialog::okClicked);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
@@ -137,7 +140,7 @@ AuthDialog::AuthDialog(const QString &actionId,
         }
     }
 
-    AuthDetails *detailsDialog = new AuthDetails(details, m_actionDescription, m_appname, this);
+    AuthDetails *detailsDialog = new AuthDetails(details, m_actionDescription, this);
     detailsWidgetContainer->layout()->addWidget(detailsDialog);
 
     userCB->hide();
@@ -279,7 +282,7 @@ PolkitQt1::Identity AuthDialog::adminUserSelected() const
     return PolkitQt1::Identity::fromString(id);
 }
 
-void AuthDialog::on_userCB_currentIndexChanged(int /*index*/)
+void AuthDialog::checkSelectedUser()
 {
     PolkitQt1::Identity identity = adminUserSelected();
     // itemData is Null when "Select user" is selected
@@ -300,7 +303,7 @@ void AuthDialog::on_userCB_currentIndexChanged(int /*index*/)
 
 QString AuthDialog::password() const
 {
-    return lePassword->text();
+    return lePassword->password();
 }
 
 void AuthDialog::authenticationFailure()
@@ -318,22 +321,11 @@ void AuthDialog::authenticationFailure()
 
 AuthDetails::AuthDetails(const PolkitQt1::Details &details,
                          const PolkitQt1::ActionDescription &actionDescription,
-                         const QString &appname,
                          QWidget *parent)
     : QWidget(parent)
 {
     setupUi(this);
 
-    // better N/A than a blank space
-    if (appname.isEmpty()) {
-        QFont nameFont = app_label->font();
-        nameFont.setItalic(true);
-        app_label->setFont(nameFont);
-        app_label->setText(i18n("Not Applicable"));
-    } else {
-        app_label->setText(appname);
-    }
-
     foreach(const QString &key, details.keys()) { //krazy:exclude=foreach (Details is not a map/hash, but rather a method)
         int row = gridLayout->rowCount() + 1;
 
@@ -352,13 +344,11 @@ AuthDetails::AuthDetails(const PolkitQt1::Details &details,
         gridLayout->addWidget(valueLabel, row, 1);
     }
 
-    // replace blank description
-    // neither isEmpty() or isNull() worked (?)
-    if (actionDescription.description() == "") {
+    if (actionDescription.description().isEmpty()) {
         QFont descrFont(action_label->font());
         descrFont.setItalic(true);
         action_label->setFont(descrFont);
-        action_label->setText(i18n("Not Applicable"));
+        action_label->setText(i18n("'Description' not provided"));
     } else {
         action_label->setText(actionDescription.description());
     }
